@@ -37,8 +37,8 @@ class ARQ:
     saavn(query="attention"):
         Returns result object with 4-5 results which you can access with dot notation.
 
-    youtube(query="carry minati", limit=1):
-        Returns result object with 'limit' number of result which you can access with dot notation.
+    youtube(query="carry minati"):
+        Returns result object which you can access with dot notation.
 
     wall(query="cyberpunk"):
         Returns result object which you can access with dot notation.
@@ -60,6 +60,12 @@ class ARQ:
 
     drive(query="iron man")
         Returns result object which you can access with dot notation.
+
+    lyrics(query="So Far Away Martin Garrix")
+        Returns result object which you can access with dot notation.
+    
+    wiki(query="dog")
+        Returns result object which you can access with dot notation.
     """
 
     def __init__(self, ARQ_API):
@@ -121,7 +127,7 @@ class ARQ:
             results[i] = DotMap(data[i])
         return results
 
-    async def youtube(self, query: str, limit: str):
+    async def youtube(self, query: str):
         """
         Returns An Object.
 
@@ -134,7 +140,7 @@ class ARQ:
                         result[result_number].id | .thumbnails | .title | .long_desc | .channel | .duration | .views | .publish_time | .url_suffix
         """
         results = DotMap()
-        api = f"{self.ARQ_API}/youtube?query={query}&count={limit}"
+        api = f"{self.ARQ_API}/youtube?query={query}"
         data = await fetch(api)
         for i in range(len(data)):
             results[i] = DotMap(data[i])
@@ -264,3 +270,39 @@ class ARQ:
         for i in range(len(data)):
             results[i] = DotMap(data[i])
         return results
+
+
+    async def lyrics(self, query: str):
+        """
+        Returns An Object.
+
+                Parameters:
+                        query (str): Query to search
+                Returns:
+                        Result object (str): Results which you can access with dot notation, Ex - results.lyrics
+
+                        results.lyrics
+        """
+        results = DotMap()
+        api = f"{self.ARQ_API}/lyrics?query={query}"
+        data = await fetch(api)
+        results = DotMap(data)
+        return results
+
+
+    async def wiki(self, query: str):
+        """
+        Returns An Object.
+
+                Parameters:
+                        query (str): Query to search
+                Returns:
+                        Result object (str): Results which you can access with dot notation, Ex - results.title
+
+                        results.title | .answer
+        """
+        results = DotMap()
+        api = f"{self.ARQ_API}/wiki?query={query}"
+        data = await fetch(api)
+        results = DotMap(data)
+        return results
